==> php82-nextcloud-29.0.7.tgz: share/nextcloud/apps/federatedfilesharing/l10n/it.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "ID di cloud federata non valido",
    "Server to server sharing is not enabled on this server" : "La condivisione tra server non è abilitata su questo server",
    "Couldn't establish a federated share." : "Impossibile stabilire una condivisione federata.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Impossibile stabilire una condivisione federata, forse la password non è corretta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Richiesta della condivisione federata inviata, riceverai un invito. Controlla le tue notifiche.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Impossibile stabilire una condivisione federata, sembra che il server da federare sia troppo datato (Nextcloud  <= 9).",
    "It is not allowed to send federated group shares from this server." : "Non è consentito inviare condivisioni di gruppo federate da questo server.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Condivisione di %1$s non riuscita, poiché l'elemento è già condiviso con l'account %2$s",
    "Not allowed to create a federated share to the same account" : "Non è consentito creare una condivisione federata con lo stesso account",
    "Federated shares require read permissions" : "Le condivisioni federate richiedono i permessi di lettura",
    "File is already shared with %s" : "Il file è già condiviso con %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "La condivisione di %1$s non è riuscita, impossibile trovare %2$s, è probabile che il server non sia al momento raggiungibile o che utilizzi un certificato auto-firmato.",
    "Could not find share" : "Impossibile trovare la condivisione",
    "Federated sharing" : "Condivisione federata",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Hai ricevuto {share} come condivisione remota da {user} (per conto di {behalf})",
    "You received {share} as a remote share from {user}" : "Hai ricevuto {share} come condivisione remota da {user}",
    "Accept" : "Accetta",
    "Decline" : "Rifiuta",
    "Federated Cloud Sharing" : "Condivisione cloud federata",
    "Sharing" : "Condivisione",
    "Federated file sharing" : "Condivisione file federata",
    "Provide federated file sharing across servers" : "Fornisce una condivisione di file federata tra server",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Regola come le persone possono condividere tra i server. Ciò include anche le condivisioni tra persone in questo server se usano la condivisione federata.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Consenti alle persone su questo server di inviare condivisioni ad altri server (questa opzione consente anche l'accesso WebDAV alle condivisioni pubbliche)",
    "Allow people on this server to receive shares from other servers" : "Consenti alle persone su questo server di ricevere condivisioni da altri server",
    "Allow people on this server to send shares to groups on other servers" : "Consenti alle persone su questo server di inviare condivisioni a gruppi su altri server",
    "Allow people on this server to receive group shares from other servers" : "Consenti alle persone su questo server di ricevere condivisioni di gruppo da altri server",
    "Search global and public address book for people" : "Cerca persone nella rubrica globale e pubblica",
    "Allow people to publish their data to a global and public address book" : "Consenti alle persone di pubblicare i propri dati in una rubrica globale e pubblica",
    "Unable to update federated files sharing config" : "Impossibile aggiornare la configurazione della condivisione federata dei file",
    "Federated Cloud" : "Cloud federata",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Puoi condividere con chiunque utilizzi server Nextcloud o altri server e servizi Open Cloud Mesh (OCM) compatibili. Ti basta inserire il loro ID di cloud federata nella finestra di condivisione. Assomiglia a persona@cloud.esempio.com ",
    "Your Federated Cloud ID:" : "Il tuo ID di cloud federata:",
    "Share it so your friends can share files with you:" : "Condividilo in modo che i tuoi amici possano condividere file con te:",
    "Facebook" : "Facebook",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Add to your website" : "Aggiungi al tuo sito web",
    "Share with me via Nextcloud" : "Condividi con me tramite Nextcloud",
    "HTML Code:" : "Codice HTML:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Condividi con me attraverso il mio ID di cloud federato #Nextcloud, vedi {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Condividi con me attraverso il mio ID di cloud federata #Nextcloud",
    "Cloud ID copied to the clipboard" : "ID di cloud copiato negli appunti",
    "Copy to clipboard" : "Copia negli appunti",
    "Clipboard is not available" : "Appunti non disponibili",
    "Copied!" : "Copiato!",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vuoi aggiungere la condivisione remota {name} da {owner}@{remote}?",
    "Remote share" : "Condivisione remota",
    "Remote share password" : "Password della condivisione remota",
    "Cancel" : "Annulla",
    "Add remote share" : "Aggiungi condivisione remota",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Condivisione di %1$s non riuscita, poiché l'elemento è già condiviso con l'utente %2$s",
    "Not allowed to create a federated share with the same user" : "Non è consentito creare una condivisione federata con lo stesso utente",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Regola come le persone possono condividere tra i server. Ciò include anche le condivisioni tra utenti in questo server se usano la condivisione federata.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Consenti agli utenti su questo server di inviare condivisioni ad altri server (questa opzione consente anche l'accesso WebDAV alle condivisioni pubbliche)",
    "Allow users on this server to receive shares from other servers" : "Consenti agli utenti su questo server di ricevere condivisioni da altri server",
    "Allow users on this server to send shares to groups on other servers" : "Consenti agli utenti su questo server di inviare condivisioni a gruppi su altri server",
    "Allow users on this server to receive group shares from other servers" : "Consenti agli utenti su questo server di ricevere condivisioni di gruppo da altri server",
    "Search global and public address book for users" : "Cerca gli utenti nella rubrica globale e pubblica",
    "Allow users to publish their data to a global and public address book" : "Consenti agli utenti di pubblicare i propri dati in una rubrica globale e pubblica"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> php82-nextcloud-29.0.8.tgz: share/nextcloud/apps/federatedfilesharing/l10n/it.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "ID di cloud federata non valido",
    "Server to server sharing is not enabled on this server" : "La condivisione tra server non è abilitata su questo server",
    "Couldn't establish a federated share." : "Impossibile stabilire una condivisione federata.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Impossibile stabilire una condivisione federata, forse la password non è corretta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Richiesta della condivisione federata inviata, riceverai un invito. Controlla le tue notifiche.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Impossibile stabilire una condivisione federata, sembra che il server da federare sia troppo datato (Nextcloud  <= 9).",
    "It is not allowed to send federated group shares from this server." : "Non è consentito inviare condivisioni di gruppo federate da questo server.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Condivisione di %1$s non riuscita, poiché l'elemento è già condiviso con l'account %2$s",
    "Not allowed to create a federated share to the same account" : "Non è consentito creare una condivisione federata con lo stesso account",
    "Federated shares require read permissions" : "Le condivisioni federate richiedono i permessi di lettura",
    "File is already shared with %s" : "Il file è già condiviso con %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "La condivisione di %1$s non è riuscita, impossibile trovare %2$s, è probabile che il server non sia al momento raggiungibile o che utilizzi un certificato auto-firmato.",
    "Could not find share" : "Impossibile trovare la condivisione",
    "Federated sharing" : "Condivisione federata",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Hai ricevuto {share} come condivisione remota da {user} (per conto di {behalf})",
    "You received {share} as a remote share from {user}" : "Hai ricevuto {share} come condivisione remota da {user}",
    "Accept" : "Accetta",
    "Decline" : "Rifiuta",
    "Federated Cloud Sharing" : "Condivisione cloud federata",
    "Sharing" : "Condivisione",
    "Federated file sharing" : "Condivisione file federata",
    "Provide federated file sharing across servers" : "Fornisce una condivisione di file federata tra server",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Regola come le persone possono condividere tra i server. Ciò include anche le condivisioni tra persone in questo server se usano la condivisione federata.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Consenti alle persone su questo server di inviare condivisioni ad altri server (questa opzione consente anche l'accesso WebDAV alle condivisioni pubbliche)",
    "Allow people on this server to receive shares from other servers" : "Consenti alle persone su questo server di ricevere condivisioni da altri server",
    "Allow people on this server to send shares to groups on other servers" : "Consenti alle persone su questo server di inviare condivisioni a gruppi su altri server",
    "Allow people on this server to receive group shares from other servers" : "Consenti alle persone su questo server di ricevere condivisioni di gruppo da altri server",
    "Search global and public address book for people" : "Cerca persone nella rubrica globale e pubblica",
    "Allow people to publish their data to a global and public address book" : "Consenti alle persone di pubblicare i propri dati in una rubrica globale e pubblica",
    "Unable to update federated files sharing config" : "Impossibile aggiornare la configurazione della condivisione federata dei file",
    "Federated Cloud" : "Cloud federata",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Puoi condividere con chiunque utilizzi server Nextcloud o altri server e servizi Open Cloud Mesh (OCM) compatibili. Ti basta inserire il loro ID di cloud federata nella finestra di condivisione. Assomiglia a persona@cloud.esempio.com ",
    "Your Federated Cloud ID:" : "Il tuo ID di cloud federata:",
    "Share it so your friends can share files with you:" : "Condividilo in modo che i tuoi amici possano condividere file con te:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (ex Twitter)",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Aggiungi al tuo sito web",
    "Share with me via Nextcloud" : "Condividi con me tramite Nextcloud",
    "HTML Code:" : "Codice HTML:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Condividi con me attraverso il mio ID di cloud federato #Nextcloud, vedi {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Condividi con me attraverso il mio ID di cloud federata #Nextcloud",
    "Cloud ID copied to the clipboard" : "ID di cloud copiato negli appunti",
    "Copy to clipboard" : "Copia negli appunti",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vuoi aggiungere la condivisione remota {name} da {owner}@{remote}?",
    "Remote share" : "Condivisione remota",
    "Remote share password" : "Password della condivisione remota",
    "Cancel" : "Annulla",
    "Add remote share" : "Aggiungi condivisione remota",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Condivisione di %1$s non riuscita, poiché l'elemento è già condiviso con l'utente %2$s",
    "Not allowed to create a federated share with the same user" : "Non è consentito creare una condivisione federata con lo stesso utente",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Regola come le persone possono condividere tra i server. Ciò include anche le condivisioni tra utenti in questo server se usano la condivisione federata.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Consenti agli utenti su questo server di inviare condivisioni ad altri server (questa opzione consente anche l'accesso WebDAV alle condivisioni pubbliche)",
    "Allow users on this server to receive shares from other servers" : "Consenti agli utenti su questo server di ricevere condivisioni da altri server",
    "Allow users on this server to send shares to groups on other servers" : "Consenti agli utenti su questo server di inviare condivisioni a gruppi su altri server",
    "Allow users on this server to receive group shares from other servers" : "Consenti agli utenti su questo server di ricevere condivisioni di gruppo da altri server",
    "Search global and public address book for users" : "Cerca gli utenti nella rubrica globale e pubblica",
    "Allow users to publish their data to a global and public address book" : "Consenti agli utenti di pubblicare i propri dati in una rubrica globale e pubblica",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Clipboard is not available" : "Appunti non disponibili",
    "Copied!" : "Copiato!"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
